OC.L10N.register(
    "circles",
    {
    "Teams" : "Тимови",
    "You created the team {circle}" : "Направили сте тим {circle}",
    "{author} created the team {circle}" : "{author} је направио тим {circle}",
    "You deleted {circle}" : "Обрисали сте круг {circle}",
    "{author} deleted {circle}" : "{author} је обрисао круг {circle}",
    "You made {member} join {circle}" : "Учинили сте да се {member} придружи кругу {circle}",
    "{author} made {member} join {circle}" : "{author} је учинио да се {member} придружи кругу {circle}",
    "You added team {member} as member to {circle}" : "Додали сте тим {member} као члана у {circle}",
    "{author} added team {member} as member to {circle}" : "{author} је додао тим {member} као члана {circle}",
    "You made {member} leave {circle}" : "Учинили сте да {member} напусти круг {circle}",
    "{author} made {member} leave {circle}" : "{author} је учинио да {member} напусти круг {circle}",
    "You removed {member} from {circle}" : "Уклонили сте корисника {member} из круга {circle}",
    "{author} removed {member} from {circle}" : "{author} је уклонио {member} из {circle}",
    "You joined {circle}" : "Придружили сте се кругу {circle}",
    "{member} joined {circle}" : "{member} се придружио кругу {circle}",
    "You accepted the invitation to join {circle}" : "Прихватили сте позив да се придружите кругу {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} је прихватио позив да се придружи кругу {circle}",
    "You added {member} as member to {circle}" : "Додали сте корисника {member} као члана у круг {circle}",
    "You have been added as member to {circle} by {author}" : "{author} Вас је додао као члана у круг {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} је додао корисника {member} у круг {circle}",
    "You added {external} to {circle}" : "Додали сте {external} у круг {circle}",
    "{external} has been added to {circle} by {author}" : "{author} је додао {external} у круг{circle}",
    "You accepted {member}'s request to join {circle}" : "Прихватили сте захтев корисника {member} да се придружите кругу {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} је прихватио Ваш позив да се придружите кругу {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} је прихватио захтев корисника {member} да се придружи кругу {circle} ",
    "You left {circle}" : "Напустили сте круг {circle}",
    "{member} left {circle}" : "{member} је напустио круг {circle}",
    "You declined the invitation to join {circle}" : "Одбили сте позивницу да се придружите кругу {circle}",
    "{member} declined an invitation to join {circle}" : "{member} је одбио позивницу да се придружи кругу {circle}",
    "You cancelled your request to join {circle}" : "Отказали сте захтев да се придружите кругу {circle}",
    "{member} cancelled a request to join {circle}" : "{member} је отказао захтев да се придружи кругу {circle}",
    "You have been removed from {circle} by {author}" : "{author} Вас је уклонио из круга {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} је уклонио корисника {member} из круга {circle}",
    "You removed {external} from {circle}" : "Уклонили сте {external} из круга {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} је уклонио {external} из круга {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Отказали сте позивницу кориснику {member} да се придружи кругу {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} је поништио Вашу позивницу да се придружите кругу {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} је поништио позивницу корисника {member} да се придружи кругу {circle}",
    "You dismissed {member}'s request to join {circle}" : "Одбацили сте захтев корисника {member} да се придружи кругу {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} је одбацио Ваш захтев да се придружите кругу {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} је одбацио захтев корисника {member} да се придружи кругу {circle}",
    "You invited {member} to join {circle}" : "Позвали сте корисника {member} да се придружи кругу {circle}",
    "You have been invited to join {circle} by {author}" : "{author} Вас је позвао да се придружите кругу {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} је позвао корисника {member} да се придружи кругу {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Променили сте ниво корисника {member} у кругу {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} је променио Ваш ниво у кругу {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} је променио ниво корисника {member} у кругу {circle} на %1$s",
    "You sent a request to join {circle}" : "Послали сте захтев да се придружите кругу {circle}",
    "{member} sent a request to join {circle}" : "{member} је послао захтев да се придружи кругу {circle}",
    "You are the new owner of {circle}" : "Ви сте нови власник круга {circle}",
    "{member} is the new owner of {circle}" : "{member} је нови власник круга {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "На догађаје који се дешавају у <strong>тиму</strong> чији сте члан",
    "Any important event in a <strong>team</strong> you are moderating" : "Било који битан догађај у <strong>тиму</strong> који модеришете",
    "On global events happening in any <strong>team</strong>" : "На глобалне догађаје који се дешавају и било ком <strong>тиму</strong>",
    "Single" : "Сам",
    "Personal" : "Лични",
    "System" : "Систем",
    "Visible" : "Видљив",
    "Open" : "Отвори",
    "Invite" : "Позив",
    "Join request" : "Захтев за приступање",
    "Friends" : "Пријатељи",
    "Password protected" : "Заштићено лозинком",
    "No Owner" : "Без власника",
    "Hidden" : "Сакривен",
    "Backend" : "Позадински систем",
    "Local" : "Локално",
    "Root" : "Корен",
    "Team invite" : "Позивница тима",
    "Federated" : "Здружено",
    "Mount point" : "Тачка монтирања",
    "Nextcloud Account" : "Nextcloud налог",
    "Nextcloud Group" : "Nextcloud група",
    "Email address" : "Адреса е-поште",
    "Contact" : "Контакт",
    "Team" : "Тим",
    "Nextcloud App" : "Nextcloud апликација",
    "Teams App" : "Апликација Тимови",
    "Admin Command Line" : "Админ Командна линија",
    "Member" : "Члан",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Власник",
    "%s shared »%s« with you." : "%s је поделио »%s« са Вама.",
    "%s shared »%s« with \"%s\"." : "%s је поделио »%s« са „%s.",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s је са вама поделио »%2$s«.\nТребало би да сте већ примили посебан и-мејл са линком за приступ.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s је са вама поделио »%2$s«. Требало би да сте већ примили посебан и-мејл са линком за приступ.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s Вам је поделио/ла лозинку за приступ „%1$s“",
    "Password to access »%s«" : "Лозинка за приступ „%s“",
    "It is protected with the following password:" : "Заштићена је следећом лозинком:",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "Click the button below to open it." : "Кликните дугме испод да га отворите.",
    "Open »%s«" : "Отвори »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s је са вама поделио више фајлова.\nТребало би да сте већ примили посебан и-мејл са линком за приступ.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s је са вама поделио више фајлова. Требало би да сте већ примили посебан и-мејл са линком за приступ.",
    "Password to access files shared to you by %1$s" : "Лозинка да приступите фајлова које Вам је поделио %1$s",
    "Password to access files" : "Лозинка за приступ фајловима",
    "%s shared multiple files with \"%s\"." : "%s је поделио више фајлова са „%s.",
    "%s shared multiple files with you." : "%s је поделио више фајлова са Вама.",
    "Boot up" : "Подизање система",
    "Nextcloud Initialization" : "Nextcloud иницијализација",
    "Circles App Initialization" : "Иницијализација апликације Кругови",
    "Fresh installation status" : "Статус свеже инсталације",
    "Building Local Database" : "Изградња локалне базе података",
    "Testing Basic Circle Creation" : "Тестирање креирања основног круга",
    "Adding local users and moderators" : "Додавање локалних корисника и модератора",
    "Show all teams" : "Прикажи све тимове",
    "Create a new team" : "Креирај нови тим",
    "Files" : "Фајлови",
    "This feature is not available for personal circles" : "Ова функционалност није доступна за личне кругове",
    "The team is not federated" : "Круг није федерисан",
    "You cannot join this team" : "Не можете да се придружите овом тиму",
    "This member is not a moderator" : "Овај члан није модератор",
    "Insufficient privileges" : "Недовољне дозволе",
    "This member does not exist" : "Члан не постоји",
    "This member is the owner of the team" : "Овај члан је власник тима",
    "Level cannot be changed for this type of member" : "Ниво не може да се промени за овај тип члана",
    "You are already a member of this circle" : "Већ сте члан овог круга",
    "You have been blocked from this circle" : "Блокирани сте у овом кругу",
    "The account is already a member of this circle" : "Овај налог је већ члан овог круга",
    "The account has already been invited into this circle" : "Налог је већ раније позван у овај круг",
    "%s (Team owned by %s)" : "%s (Власник тима је %s)",
    "You are now a member of the Team \"%2$s\"" : "Сада сте члан тима „%2$s“",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s Вас је позвао/ла у Тим „%2$s“",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s је послао захтев да буде члан Тима „%2$s“",
    "Accept" : "Прихвати",
    "Refuse" : "Одбиј",
    "Leave the team" : "Напусти тим",
    "%s" : "%s",
    "Personal team" : "Лични тим",
    "%s owned by %s" : "%s поседује %s",
    "You have no permission to create a new team" : "Немате дозволу да креирате нови тим",
    "%s shared a file with \"%s\"." : "%s је поделио фајл са „%s.",
    "%s shared a file with you." : "%s је са вама поделио фајл.",
    "%1$s shared %2$s with %3$s" : "%1$s је поделио %2$s са %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s је поделио %2$s са „%3$s”",
    "Open %s" : "Отвори %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s је са вама поделио неки садржај.\nТребало би да сте већ примили посебан и-мејл са линком за приступ.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s је поделио са вама неки садржај. Требало би да сте већ примили посебан и-мејл са линком за приступ.",
    "Password to access content shared with you by %1$s" : "%1$s је са вама поделио лозинку за приступ садржају",
    "Password to access content" : "Лозинка за приступ садржају",
    "This item is already shared with this team" : "Ова ставка је већ подељена овом тиму",
    "Bring cloud-users closer together." : "Приближимо клауд кориснике.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Тимови омогућава људима да креирају своје сопствене групе људи/колега/пријатеља.\nБило која друга апликација затим може за дељење да користи те групе људи.",
    "Failed to load teams" : "Није успело учитавање тимова",
    "Try again" : "Покушајте поново",
    "No teams found" : "Није пронађен ниједан тим",
    "Join or create teams to see them here." : "Приступите им или креирајте тимове да их видите овде.",
    "Create your first team" : "Креирајте свој први тим",
    "Loading…" : "Учитавам…",
    "More teams" : "Још тимова",
    "No files in here" : "Овде нема фајлова",
    "No entries found in this folder" : "Нема резултата у овој фасцикли",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "Teams' files" : "Фајлови тимова",
    "Select team to filter by" : "Изаберите тим по којем се филтрира",
    "Please select teams to filter by" : "Молимо васд да изаберите тимове по којима се филтрира",
    "No files found for the selected teams" : "Није пронађен ниједан фајл за изабране тимове",
    "Shared to Circles" : "Дељено на Кругове",
    "Circle" : "Круг"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
